@@ -16,12 +16,9 @@ mention this dependency.)
 __Author__ = "Greg J. Badros <badros@gmail.com>"
 __copyright__ = "Copyright 2019, Greg J. Badros"
 
-from time import (localtime, mktime)
 import logging
 import socket
 import select
-import re
-import requests
 
 # urllib.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 _LOGGER = logging.getLogger(__name__)
@@ -34,26 +31,6 @@ class MoIP(object):
     reading status, and issuing state changes.
     """
 
-    def parse(self, xml_str):
-        """Main entrypoint into the parser. It gets the state of the strip."""
-
-        import xml.etree.ElementTree as ET
-
-        root = ET.fromstring(xml_str)
-        self._hostname = root.find('host_name').text
-        self._hardware_version = root.find('hardware_version').text
-        self._serial_number = root.find('serial_number').text
-        self._has_ups = root.find('hasUPS').text == '1'
-        self._voltage = int(root.find('voltage_value').text)/10
-        self._current = int(root.find('current_value').text)/10
-        self._power = int(root.find('power_value').text)
-        self._cloud_status = root.find('cloud_status').text == '1'
-        outlet_names = root.find('outlet_name').text.split(',')
-        outlet_status = root.find('outlet_status').text.split(',')
-        for (i, (name, state)) in enumerate(zip(outlet_names, outlet_status)):
-            self._switches.append(Switch(self, i, name, state == '1'))
-        return True
-
     # pylint: disable=too-many-instance-attributes, too-many-arguments
     def __init__(self, host, username, password, area='',
                  noop_set_state=False):
@@ -194,8 +171,17 @@ class MoIP(object):
     def _update(self, xml_str=None):
         pass
 
+    def __str__(self):
+        return "MoIP Controller @ %s [%s]" % (
+            self._host,
+            self._firmware_version)
 
-class MoIP_Receiver:
+    def __repr__(self):
+        return str({'host': self._host,
+                    'firmware_version': self._firmware_version})
+
+
+class MoIP_Receiver(object):
     def __init__(self, mc, num, name, input=None):
         self._mc = mc
         self._num = num
@@ -246,13 +232,19 @@ class MoIP_Receiver:
     def set_cec(self, cec_on):
         self._send_check("!CEC=%s,%d" % (self._num, 1 if cec_on else 0))
 
-    def __repr__(self):
+    def __str__(self):
         return "{MoIP Rx#%d \"%s\" from %s}" % (self._num,
                                                 self._name,
                                                 self._input)
 
+    def __repr__(self):
+        return str({'name': self._name,
+                    'num': self._num,
+                    'input': self._input and self._input.num,
+                    'mc': self._mc})
 
-class MoIP_Transmitter:
+
+class MoIP_Transmitter(object):
     def __init__(self, mc, num, name):
         self._mc = mc
         self._num = num
@@ -266,9 +258,11 @@ class MoIP_Transmitter:
     def name(self):
         return self._name
 
-    def str(self):
-        return "self._name (Tx#%s)" % (self._num)
-    
-    def __repr__(self):
+    def __str__(self):
         return "{MoIP Tx#%d \"%s\"}" % (self._num,
                                         self._name)
+
+    def __repr__(self):
+        return str({'name': self._name,
+                    'num': self._num,
+                    'mc': self._mc})
